@@ -38,6 +38,7 @@
 #include <TelepathyQt/PendingReady>
 #include <TelepathyQt/TextChannel>
 
+#include <KTp/actions.h>
 #include <KTp/contact-factory.h>
 #include <KTp/types.h>
 #include <KTp/Widgets/add-contact-dialog.h>
@@ -57,6 +58,7 @@
 #include <KToolInvocation>
 #include <KMenuBar>
 #include <KStandardAction>
+#include <KWindowSystem>
 
 #include "ui_main-widget.h"
 #include "account-buttons-panel.h"
@@ -64,8 +66,6 @@
 #include "tooltips/tooltipmanager.h"
 #include "context-menu.h"
 
-#define PREFERRED_TEXTCHAT_HANDLER "org.freedesktop.Telepathy.Client.KDE.TextUi"
-
 bool kde_tp_filter_contacts_by_publication_status(const Tp::ContactPtr &contact)
 {
     return contact->publishState() == Tp::Contact::PresenceStateAsk;
@@ -238,13 +238,7 @@ void MainWidget::onJoinChatRoomRequested()
         // check account validity. Should NEVER be invalid
         if (!account.isNull()) {
             // ensure chat room
-            Tp::ChannelRequestHints hints;
-            hints.setHint("org.kde.telepathy","forceRaiseWindow", QVariant(true));
-
-            Tp::PendingChannelRequest *channelRequest = account->ensureTextChatroom(dialog.data()->selectedChatRoom(),
-                                                                                    QDateTime::currentDateTime(),
-                                                                                    PREFERRED_TEXTCHAT_HANDLER,
-                                                                                    hints);
+            Tp::PendingChannelRequest *channelRequest = KTp::Actions::startGroupChat(account, dialog.data()->selectedChatRoom());
 
             connect(channelRequest, SIGNAL(finished(Tp::PendingOperation*)), SLOT(onGenericOperationFinished(Tp::PendingOperation*)));
         }
@@ -516,7 +510,7 @@ KAction *MainWidget::createAction(const QString& text, QObject *signalReceiver,
 void MainWidget::setupActions(const KConfigGroup& guiConfigGroup)
 {
     m_settingsDialog = KStandardAction::preferences(m_contactsListView, SLOT(showSettingsKCM()),this);
-    m_settingsDialog->setText(i18n("Settings")); // We set text manually since standard name is too long
+    m_settingsDialog->setText(i18n("Instant Messaging Settings...")); // We set text manually since standard name is too long
 
     m_quitAction = KStandardAction::quit(this, SLOT(close()), this);
     m_quitAction->setMenuRole(QAction::QuitRole);
@@ -529,16 +523,16 @@ void MainWidget::setupActions(const KConfigGroup& guiConfigGroup)
     m_searchContactAction->setShortcut(KStandardShortcut::find());
 
     // Dual actions
-    m_groupContactsAction = new KDualAction(i18n("Show contacts by groups"),
-                                            i18n("Show contacts by accounts"),
+    m_groupContactsAction = new KDualAction(i18n("Show Contacts by Groups"),
+                                            i18n("Show Contacts by Accounts"),
                                             this);
     m_groupContactsAction->setActiveIcon(KIcon("user-group-properties"));
     m_groupContactsAction->setInactiveIcon(KIcon("user-group-properties"));
     m_groupContactsAction->setCheckable(true);
     m_groupContactsAction->setChecked(true);
 
-    m_showOfflineAction = new KDualAction(i18n("Show offline contacts"),
-                                          i18n("Show offline contacts"),
+    m_showOfflineAction = new KDualAction(i18n("Show Offline Contacts"),
+                                          i18n("Hide Offline Contacts"),
                                           this);
     m_showOfflineAction->setActiveIcon(KIcon("meeting-attending-tentative"));
     m_showOfflineAction->setInactiveIcon(KIcon("meeting-attending-tentative"));
@@ -546,8 +540,8 @@ void MainWidget::setupActions(const KConfigGroup& guiConfigGroup)
     m_showOfflineAction->setChecked(false);
     m_showOfflineAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
 
-    m_sortByPresenceAction = new KDualAction(i18n("Sorted by name"),
-                                             i18n("Sorted by presence"),
+    m_sortByPresenceAction = new KDualAction(i18n("Sort by Presence"),
+                                             i18n("Sort by Name"),
                                              this);
     m_sortByPresenceAction->setActiveIcon(KIcon("sort-presence"));
     m_sortByPresenceAction->setInactiveIcon(KIcon("sort-name"));
@@ -568,12 +562,21 @@ void MainWidget::setupActions(const KConfigGroup& guiConfigGroup)
     QString shownContacts = guiConfigGroup.readEntry("shown_contacts", "unblocked");
     m_blockedFilterGroup = new QActionGroup(this);
     m_blockedFilterGroup->setExclusive(true);
-    m_blockedFilterGroup->addAction(createAction(i18n("Show all contacts"), m_contactsListView, SLOT(onShowAllContacts()),
+    m_blockedFilterGroup->addAction(createAction(i18n("Show All Contacts"), m_contactsListView, SLOT(onShowAllContacts()),
                                                 shownContacts == QLatin1String("all")));
-    m_blockedFilterGroup->addAction(createAction(i18n("Show unblocked contacts"), m_contactsListView, SLOT(onShowUnblockedContacts()),
+    m_blockedFilterGroup->addAction(createAction(i18n("Show Unblocked Contacts"), m_contactsListView, SLOT(onShowUnblockedContacts()),
                                                 shownContacts == QLatin1String("unblocked")));
-    m_blockedFilterGroup->addAction(createAction(i18n("Show blocked contacts"), m_contactsListView, SLOT(onShowBlockedContacts()),
+    m_blockedFilterGroup->addAction(createAction(i18n("Show Blocked Contacts"), m_contactsListView, SLOT(onShowBlockedContacts()),
                                                 shownContacts == QLatin1String("blocked")));
 }
 
+void MainWidget::toggleWindowVisibility()
+{
+    if (isActiveWindow()) {
+        close();
+    } else {
+        KWindowSystem::forceActiveWindow(this->effectiveWinId());
+    }
+}
+
 #include "main-widget.moc"
